@@ -57,11 +57,11 @@ App::Dochazka::REST - Dochazka REST server
 
 =head1 VERSION
 
-Version 0.352
+Version 0.400
 
 =cut
 
-our $VERSION = '0.352';
+our $VERSION = '0.400';
 
 
 =head2 Development status
@@ -87,28 +87,27 @@ The module also contains documentation of the Dochazka REST server as a whole.
 =head1 DESCRIPTION
 
 This distribution, L<App::Dochazka::REST>, including all the modules in C<lib/>,
-the scripts in C<bin/>, and the configuration files in C<config/>, constitute 
+the scripts in C<bin/>, and the configuration files in C<config/>, constitutes
 the REST server component of Dochazka, the open-source Attendance/Time Tracking
 (ATT) system. 
 
-Dochazka as a whole aims to be a convenient, open-source ATT solution. Its
-reference implementation runs on the Linux platform. 
+Dochazka as a whole aims to be a convenient, open-source ATT solution.
 
 
 =head2 Architecture
 
-Dochazka consists of three main components, a simplified overview of which
-could be:
+Dochazka consists of three main components:
 
 =over
 
 =item * REST server (this module)
 
-The REST server listens for HTTP requests on a pre-defined port. If an incoming
-requests is determined to be authorized and provided it resolves to a
-"resource" (more on that below), it dispatches it to the resource handler (part
-of the REST server), which it into one or more SQL statements which are sent
-to the PostgreSQL database.
+The REST server listens for and processes incoming HTTP requests. Processing includes
+authentication and authorization. The server attempts to map the request URI to a 
+Dochazka resource. The resource handler takes action on the request, depending on the
+HTTP method (GET, PUT, POST, DELETE). Typically, this action will culminate in 
+one or more SQL statements which are sent to the PostgreSQL database for
+execution. The results are sent back to the client in the HTTP reponse.
 
 =item * PostgreSQL database
 
@@ -117,22 +116,282 @@ from the REST server. Based on these statements, it creates, retrieves,
 updates, and deletes (CRUD) employee attendance records and related data in the
 Dochazka database.
 
-The PostgreSQL database can be located on the same machine as the REST server,
-or on a remote machine.
-
-=item * one or more Dochazka clients
+=item * Dochazka clients
 
 Dochazka clients, such as L<App::Dochazka::WWW>, L<App::Dochazka::CLI>, and
-perhaps others, try to divine user intent and translate it into HTTP requests
-to the REST server.
+perhaps others, present a user interface (UI) to employees, by which they try
+to divine their intent and express it in terms of HTTP requests to the REST
+server.
 
-Anything that communicates with the REST server via HTTP requests --
+The HTTP protocol is used in all communication between client and server. In
+Dochazka, the term "client" should be understood in a broad sense, encompassing
 stand-alone report generators, specialized administration utilities, cronjobs,
-web browsers, etc. -- falls into this category.
+web browsers, etc., in addition to the purpose-built Perl (CLI) and JavaScript
+(WWW) clients. 
 
 =back
 
 
+=head2 Client-server communication
+
+As stated above, communication between the server and its clients takes place
+using the HTTP protocol. At an even more fundamental level, the communication
+takes the form of requests (from client to server) and responses (from server
+back to client) to those requests. In other words, communication is never
+initiated by the server, but always by the clients.
+
+=head3 HTTP request
+
+An HTTP request has the following basic components:
+
+=over
+
+=item * Method (GET, PUT, POST, or DELETE)
+
+=item * URI (Universal Resource Indicator)
+
+=item * Headers
+
+=item * Content body (or "request entity" - PUT, POST, DELETE only)
+
+=back
+
+=head4 Method
+
+The Dochazka REST server accepts the following HTTP methods:  C<PUT>,
+C<POST>, and C<DELETE>.
+
+=over
+
+=item C<GET>
+
+A C<GET> request on a resource is a request for information - in other words,
+it is "read-only": C<GET> requests never change the underlying data. In
+SQL terms, C<GET> requests are typically mapped to C<SELECT> statements.
+
+=item C<PUT>
+
+C<PUT> requests always refer to a concrete data entity, or chunk of data.
+Typically this will be a record in the underlying database. If the record
+already exists, the C<PUT> request is interpreted to mean modification (or
+C<UPDATE> in SQL). If the record does not exist, then the request will map to
+an C<INSERT> statement to create the resource. If the request causes a new
+resource to be created, the location of the new resource should be returned in
+the response headers.
+
+=item C<POST>
+
+Sometimes, especially for create operations, the exact specification of the
+resource is not known beforehand. To address these cases, some resources accept
+C<POST> requests. Like with C<PUT>, links to newly created resources are
+supposed to be returned in the response headers.
+
+=item C<DELETE>
+
+As their name would suggest, C<DELETE> requests are issued when we want to
+dissolve or destroy a resource. Whether or not this actually happens is
+determined by two factors: (1) whether the user issuing the request has the
+requisite authorization and, (2), whether the underlying data record is
+referred to by other records - in which case typically the C<DELETE> request
+will fail.
+
+=back
+
+Of these four methods, only two (C<GET> and C<POST>) really get used much on
+the World Wide Web. Still, they are part of the HTTP standard and they are
+useful for our purposes.
+
+
+=head4 URI
+
+The purpose of the Universal Resource Indicator (URI, sometimes also known as
+an URL) is to uniquely identify a resource.
+
+While Dochazka only accepts four HTTP methods, the number of URIs it will
+accept is much higher.
+
+URIs consist of several syntactical elements. An exhaustive description can be
+found in RFC ..., but for Dochazka purposes we can present them as follows:
+
+=over
+
+=item C<https://>
+
+This part of the URI says that we are using the HTTPS protocol (or SSL-encrypted
+HTTP) to communicate. It is separated from the next component by two forward
+slashes.
+
+=item C<dochazka.site/>
+
+After the protocol, the next URI component is the REST server's domain name.
+Obviously, this will differ from site to site. It is separated from the next
+component by a single forward slash.
+
+=item Dochazka resource
+
+As stated above, the domain name is terminated by a single forward slash.
+Everything after that is interpreted as a resource specification. 
+
+=back
+
+Of these three components, the first two can be abstracted away as site-specific. 
+Once the application's implementation at a given site has stabilized, these two
+URI components will change very seldomly, if at all.
+
+Dochazka resources, on the other hand, are much more ephemeral. Different resources
+present different ways that users can access and modify the data (in this case,
+attendance data) in the underlying database. Some resources, such as
+C<employee/nick/simona>, refer directly to a unit of information that may or
+may not exist in the database information. Other resources, like
+C<interval/new>, are not linked to a specific database record.
+
+(Regardless of how we think of them, internally all resources resolve to
+function calls. The function in this case is referred to as the "dispatch
+target" and the argument provided in the function call is the "request
+context".)
+
+Some resources accept all four HTTP methods listed above, others accept two or
+three, and still others accept only one.
+
+
+=head4 Headers
+
+HTTP headers are somewhat obscure because they are often hidden by the 
+client. Nevertheless, they are an important part of the HTTP protocol. The
+Dochazka REST server only accepts certain headers in the request.
+
+#FIXME: describe the more common response headers
+
+
+=head4 Body
+
+C<PUT> and C<POST> requests may take a request body. If a request body is
+expected or accepted, it must be a valid JSON string. (JSON is a simple way of
+"stringifying" a data structure.)
+
+
+=head3 HTTP response
+
+The HTTP response returned by the REST server consists of:
+
+=over
+
+=item * Status code (e.g. 200, 400, 404, etc.)
+
+=item * Headers
+
+=item * Content body (or "response entity")
+
+=back
+
+
+=head4 Status
+
+The HTTP standard stipulates a number of status codes. The server listens for
+incoming requests. Under normal operation, the server processes each request.
+The result of such processing is a "response", which is sent back to the client
+that originated the request. Each response will contain one and only one status
+code. The meanings of the various status codes are explained in the HTTP
+standard. Some of the more common ones are as follows:
+
+=over
+
+=item C<200> (OK)
+
+The request was accepted and processed. Refer to the response body for the
+result.
+
+=item C<204> ()
+
+This code is returned on C<DELETE> requests when either the record was
+successfully deleted or the resource did not exist in the first place.
+
+=item C<404> (Not Found)
+
+The resource specification given in the URI could not be associated with a
+known resource.
+
+=item C<405> (Method Not Allowed)
+
+The resource was recognized but it is not defined for this method.
+
+=item C<401> (Not authorized)
+
+A valid method+resource combination was specified, but the user failed to
+authenticate herself to the REST server.
+
+=item C<403> (Forbidden)
+
+A valid method+resource combination was specified and the user was successfully
+authenticated, but the user is not authorized to perform the operation she is
+requesting.
+
+=item C<400> (Malformed)
+
+A valid method+resource combination was specified and the user passed
+authentication and authorization. However, the information provided by the user
+in the resource specification or in the request body could not be parsed.
+
+=back
+
+
+=head4 Headers
+
+HTTP responses are always accompanied by headers, which qualify the response in
+various ways. For example, the C<Content-Encoding> header indicates how the
+bytes in the response body string should be interpreted. In Dochazka's case, the 
+response body will always be in JSON, which implies the C<UTF-8> encoding.
+
+#FIXME: describe the more common response headers
+
+
+=head4 Body
+
+The response body holds the information returned by a "successful" request. Be
+aware that "success" in this context only means that, from the perspective of
+the REST server, the request was fully processed. It does I<not> means that 
+that whatever the user was requesting was actually done. For example, if a
+C<GET> request for a resource is sent and the reponse code is 200, the client
+programmer can assume that a response body will be present, and that it will
+be an L<App::CELL::Status> object, but that is all she can assume.
+Particularly, she cannot assume that the payload of that status object 
+contains the object requested.
+
+As stated above, the response body will always be a JSON string. This string
+can either be displayed to the user as-is, or it can be interpreted and further
+processed by the client.
+
+A body may be included in the response, provided the status code is C<200> (OK).
+For the client, an HTTP response of 200 is a signal to look into the response
+body for further information. For the purposes of Dochazka, a 200 status does
+not provide any information beyond this imperative: "look into the response
+body". 
+
+Since looking into the response body is fundamental to the operation of
+Dochazka clients, the REST server emits response bodies in a strictly defined
+format detailed in L<App::CELL::Status>. Client developers, then, can count 
+on the truthfulness of the following statements:
+
+=over
+
+=item "A response body will be sent if, and only if, the HTTP status code is 200"
+
+=item "The response body will always be a JSON string"
+
+=item "That JSON string will always be an App::CELL::Status object"
+
+=back
+
+
+
+While the HTTP protocol provides a range of general status codes, some of which
+make sense for and are used by Dochazka, in some cases Dochazka needs to return
+status codes that are not provided for by the standard. For this reason, the
+information returned by Dochazka is further encapsulated in a Dochazka-specific
+status structure, and this is what is returned in the response body.
+
+
+
 =head2 Basic parameters
 
 =head3 UTF-8
@@ -943,14 +1202,6 @@ Load site configuration and set up logging.
 =cut
 
 sub init {
-    my ( $class, @ARGS ) = @_;
-    die( "Unbalanced PARAMHASH" ) if @ARGS % 2;
-    my %ARGS = @ARGS;
-
-    # load configuration parameters and set up logging
-    my $status = $class->init_no_db( %ARGS );
-    return $status unless $status->ok;
-
     # initialize the $dbix_conn singleton
     App::Dochazka::REST::ConnBank::init_singleton(
         $site->DOCHAZKA_DBNAME,
@@ -961,11 +1212,6 @@ sub init {
     my $eids = get_eid_of( $dbix_conn, "root", "demo" );
     $site->set( 'DOCHAZKA_EID_OF_ROOT', $eids->{'root'} );
     $site->set( 'DOCHAZKA_EID_OF_DEMO', $eids->{'demo'} );
-
-    $log->info( "Configuration parameters loaded from sitedirs: " . Dumper( $meta->CELL_META_SITEDIR_LIST ) );
-    $log->info( "Starting App::Dochazka::REST server" );
-    $status->payload( Web::Machine->new( resource => 'App::Dochazka::REST::Resource', )->to_app ); 
-    return $status;
 }
 
 
