@@ -63,11 +63,11 @@ App::Dochazka::REST::Model::Employee - Employee data model
 
 =head1 VERSION
 
-Version 0.352
+Version 0.400
 
 =cut
 
-our $VERSION = '0.352';
+our $VERSION = '0.400';
 
 
 
@@ -461,6 +461,7 @@ sub noof_employees_by_priv {
         { isa => 'DBIx::Connector' },
         { type => SCALAR },
     );
+    $log->debug( "Entering " . __PACKAGE__ . "::noof_employees_by_priv with priv $priv" );
 
     if ( $priv eq 'total' ) {
         my $count = noof( $conn, 'employees' );
@@ -474,7 +475,8 @@ sub noof_employees_by_priv {
         $priv =~ m/^(passerby)|(inactive)|(active)|(admin)$/i;
 
     my $sql = $site->SQL_EMPLOYEE_COUNT_BY_PRIV_LEVEL;
-    my ( $count ) = select_single( conn => $conn, sql => $sql, keys => [ $priv ] );
+    my ( $count ) = @{ select_single( conn => $conn, sql => $sql, keys => [ $priv ] )->payload };
+    $log->debug( "select_single returned: $count" );
     $count += 0;
     $CELL->status_ok( 'DISPATCH_COUNT_EMPLOYEES', args => [ $count, $priv ], 
         payload => { 'priv' => $priv, 'count' => $count } );
