@@ -54,11 +54,11 @@ the data model
 
 =head1 VERSION
 
-Version 0.352
+Version 0.400
 
 =cut
 
-our $VERSION = '0.352';
+our $VERSION = '0.400';
 
 
 
@@ -187,6 +187,9 @@ statement.
 
 Returns a status object.
 
+Important note: it is up to the programmer to not pass any SQL statement that
+might affect more than one record.
+
 =cut
 
 sub cud {
@@ -198,7 +201,7 @@ sub cud {
         attrs => { type => ARRAYREF }, # order of attrs must match SQL statement
     } );
 
-    my $status;
+    my ( $status, $rv );
 
     try {
         local $SIG{__WARN__} = sub {
@@ -223,7 +226,7 @@ sub cud {
             } @{ $ARGS{'attrs'} }; 
 
             # execute the SQL statement
-            my $rv = $sth->execute;
+            $rv = $sth->execute;
             $log->debug( "cud: DBI execute returned " . Dumper( $rv ) );
             if ( $rv == 1 ) {
 
@@ -235,11 +238,11 @@ sub cud {
 
             } elsif ( $rv eq '0E0' ) {
 
-                # no error, but no record returned either
-                $status = $CELL->status_notice( 
-                    'DOCHAZKA_CUD_NO_RECORDS_AFFECTED', 
-                    args => [ $sth->{'Statement'} ] 
-                ); 
+                ## no error, but no record returned either
+                #$status = $CELL->status_notice( 
+                #    'DOCHAZKA_CUD_NO_RECORDS_AFFECTED', 
+                #    args => [ $sth->{'Statement'} ] 
+                #); 
             } else {
 
                 # non-standard return value
@@ -272,7 +275,8 @@ sub cud {
         }
     };
 
-    $status = $CELL->status_ok( 'DOCHAZKA_CUD_OK', payload => $ARGS{'object'} ) if not defined( $status );
+    $status = $CELL->status_ok( 'DOCHAZKA_CUD_OK', DBI_return_value => $rv, payload => $ARGS{'object'} ) 
+        unless $status;
     return $status;
 }
 
@@ -405,7 +409,7 @@ sub load_multiple {
     my $counter = scalar @$results;
     $status = ( $counter )
         ? $CELL->status_ok( 'DISPATCH_RECORDS_FOUND', 
-            args => [ $counter ], payload => $results, count => $counter )
+            args => [ $counter ], payload => $results, count => $counter, keys => $ARGS{'keys'} )
         : $CELL->status_notice( 'DISPATCH_NO_RECORDS_FOUND',
             payload => $results, count => $counter );
     $log->debug( Dumper $status );
