@@ -41,7 +41,7 @@ use warnings;
 
 use App::CELL qw( $CELL $meta $site );
 use App::Dochazka::REST::ConnBank qw( $dbix_conn conn_status );
-use App::Dochazka::REST::Dispatch::Employee qw( hash_the_password );
+use App::Dochazka::REST::Util qw( hash_the_password );
 use App::Dochazka::REST::Model::Privhistory qw( get_privhistory );
 use App::Dochazka::REST::Model::Schedhistory qw( get_schedhistory );
 use App::Dochazka::REST::Model::Shared qw( select_single );
@@ -53,6 +53,7 @@ use Params::Validate qw( :all );
 use Test::JSON;
 use Test::More;
 use Try::Tiny;
+use Web::MREST;
 
 
 
@@ -66,11 +67,11 @@ App::Dochazka::REST::Test - Test helper functions
 
 =head1 VERSION
 
-Version 0.352
+Version 0.400
 
 =cut
 
-our $VERSION = '0.352';
+our $VERSION = '0.400';
 
 
 
@@ -139,9 +140,14 @@ sub initialize_unit {
 
     require App::Dochazka::REST;
 
-    my $status = App::Dochazka::REST->init( sitedir => '/etc/dochazka-rest', verbose => 1, debug_mode => 1 );
+    my $status = Web::MREST::init( distro => 'App-Dochazka-REST' );
+    die $status->text unless $status->ok;
+
+    $status = App::Dochazka::REST->init_no_db( sitedir => '/etc/dochazka-rest', verbose => 1, debug_mode => 1 );
     return $status unless $status->ok;
 
+    App::Dochazka::REST->init;
+
     is( $status->level, 'OK' );
     ok( $site->DOCHAZKA_EID_OF_ROOT );
     ok( $site->DOCHAZKA_EID_OF_DEMO );
@@ -153,6 +159,9 @@ sub initialize_unit {
     my $rc = conn_status();
     is( $rc, "UP", "PostgreSQL database is alive" );
 
+    # add Web::Machine object to payload
+    $status->payload( Web::Machine->new( resource => 'App::Dochazka::REST::Dispatch', )->to_app );
+
     return $status;
 }
 
@@ -225,11 +234,23 @@ sub req {
     $r->authorization_basic( $user, $pass );
 
     my $res = $test->request( $r );
-    is( $res->code, $code, "$method $resource as $user " . ( $json ? "with $json" : "" ) . " 1" );
     $code += 0;
-    return unless $code == 200;
-    is_valid_json( $res->content, "$method $resource as $user " . ( $json ? "with $json" : "" ) . " 2" );
-    return status_from_json( $res->content );
+    if ( $code != $res->code ) {
+        diag( Dumper $res );
+        BAIL_OUT(0);
+    }
+    is( $res->code, $code, "$method $resource as $user " . ( $json ? "with $json" : "" ) . " 1" );
+    my $content = $res->content;
+    if ( $content ) {
+        #diag( Dumper $content );
+        is_valid_json( $res->content, "$method $resource as $user " . ( $json ? "with $json" : "" ) . " 2" );
+        my $status = status_from_json( $content );
+        if ( my $location_header = $res->header( 'Location' ) ) {
+            $status->{'location_header'} = $location_header;
+        }
+        return $status;
+    }
+    return;
 }
 
 
@@ -249,7 +270,7 @@ sub dbi_err {
     my ( $test, $code, $user, $method, $resource, $json, $qr ) = validate_pos( @_, 1, 1, 1, 1, 1, 1, 1 );
     my $status = req( $test, $code, $user, $method, $resource, $json );
     is( $status->level, 'ERR' );
-    is( $status->code, 'DOCHAZKA_DBI_ERR' );
+    ok( $status->text );
     if ( ! ( $status->text =~ $qr ) ) {
         diag( "$user $method $resource\n$json" );
         diag( $status->text . " does not match $qr" );
@@ -268,7 +289,6 @@ and resource name without quotes)
 
 sub docu_check {
     my ( $test, $resource ) = @_;
-
     #diag( "Entering " . __PACKAGE__ . "::docu_check with argument $resource" );
 
     if ( ref( $test ) ne 'Plack::Test::MockHTTP' ) {
@@ -280,10 +300,8 @@ sub docu_check {
     my $t = 0;
     my ( $docustr, $docustr_len );
     #
-    # - straight 'docu' resource
-    my $status = req( $test, 200, 'demo', 'POST', '/docu', <<"EOH" );
-{ "resource" : "$resource" }
-EOH
+    # - straight 'docu/pod' resource
+    my $status = req( $test, 200, 'demo', 'POST', '/docu/pod', "\"$resource\"" );
     is( $status->level, 'OK', $tn . ++$t );
     is( $status->code, 'DISPATCH_ONLINE_DOCUMENTATION', $tn . ++$t );
     if ( exists $status->{'payload'} ) {
@@ -297,9 +315,7 @@ EOH
     }
     #
     # - not a very thorough examination of the 'docu/html' version
-    $status = req( $test, 200, 'demo', 'POST', '/docu/html', <<"EOH" );
-{ "resource" : "$resource" }
-EOH
+    $status = req( $test, 200, 'demo', 'POST', '/docu/html', "\"$resource\"" );
     is( $status->level, 'OK', $tn . ++$t );
     is( $status->code, 'DISPATCH_ONLINE_DOCUMENTATION', $tn . ++$t );
     if ( exists $status->{'payload'} ) {
@@ -351,7 +367,7 @@ Create testing employee with 'active' privilege
 sub create_active_employee {
     my ( $test ) = @_;
     my $eid_of_active = create_testing_employee( { nick => 'active', password => 'active' } )->{'eid'};
-    my $status = req( $test, 200, 'root', 'POST', "priv/history/eid/$eid_of_active", 
+    my $status = req( $test, 201, 'root', 'POST', "priv/history/eid/$eid_of_active", 
         '{ "effective":"1000-01-01", "priv":"active" }' );
     ok( $status->ok, "Create active employee 2" );
     is( $status->code, 'DOCHAZKA_CUD_OK', "Create active employee 3" );
@@ -368,7 +384,7 @@ Create testing employee with 'active' privilege
 sub create_inactive_employee {
     my ( $test ) = @_;
     my $eid_of_inactive = create_testing_employee( { nick => 'inactive', password => 'inactive' } )->{'eid'};
-    my $status = req( $test, 200, 'root', 'POST', "priv/history/eid/$eid_of_inactive", 
+    my $status = req( $test, 201, 'root', 'POST', "priv/history/eid/$eid_of_inactive", 
         '{ "effective":"1000-01-01", "priv":"inactive" }' );
     ok( $status->ok, "Create inactive employee 2" );
     is( $status->code, 'DOCHAZKA_CUD_OK', "Create inactive employee 3" );
@@ -514,7 +530,7 @@ sub create_testing_schedule {
     my $intvls_json = JSON->new->utf8->canonical(1)->encode( $intvls );
     #
     # - request as root 
-    my $status = req( $test, 200, 'root', 'POST', "schedule/new", $intvls_json );
+    my $status = req( $test, 201, 'root', 'POST', "schedule/new", $intvls_json );
     is( $status->level, 'OK' );
     is( $status->code, 'DISPATCH_SCHEDULE_INSERT_OK' );
     ok( exists $status->{'payload'} );
