@@ -37,6 +37,7 @@ use strict;
 use warnings FATAL => 'all';
 
 use App::CELL qw( $log );
+use Authen::Passphrase::SaltedDigest;
 use Pod::Simple::HTML;
 
 
@@ -50,11 +51,11 @@ App::Dochazka::REST::Util - miscellaneous utilities
 
 =head1 VERSION
 
-Version 0.352
+Version 0.400
 
 =cut
 
-our $VERSION = '0.352';
+our $VERSION = '0.400';
 
 
 
@@ -76,20 +77,52 @@ This module provides the following exports:
 
 =over 
 
+=item L<hash_the_password> (function)
+
 =item L<pod_to_html> (function)
 
+=item L<pre_update_comparison> (function)
+
 =back
 
 =cut
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( pod_to_html );
+our @EXPORT_OK = qw( 
+    hash_the_password
+    pod_to_html 
+    pre_update_comparison
+);
 
 
 
 
 =head1 FUNCTIONS
 
+
+=head2 hash_the_password
+
+Takes a request entity (hashref) - looks for a 'password' property.
+if it is present, hashes the password with a random salt - in effect,
+this replaces the password property with passhash+salt. If there is
+no password property, the function does nothing.
+
+=cut
+
+sub hash_the_password {
+    my $entity = shift;
+    if ( $entity->{'password'} ) {
+        my $ppr = Authen::Passphrase::SaltedDigest->new(
+            algorithm => "SHA-512", salt_random => 20,
+            passphrase => $entity->{'password'}
+        );
+        delete $entity->{'password'};
+        $entity->{'passhash'} = $ppr->hash_hex;
+        $entity->{'salt'} = $ppr->salt_hex;
+    }
+}
+
+
 =head2 pod_to_html
 
 Each L<App::Dochazka::REST> resource definition includes a 'documentation'
@@ -117,4 +150,35 @@ sub pod_to_html {
 }
 
 
+=head2 pre_update_comparison
+
+Given an original object and a hashref of possible changed properties,
+compare the properties in the hashref with the corresponding properties 
+in the original object. If any properties really are changed, update
+the object. Return the number of properties so changed.
+
+=cut
+
+sub pre_update_comparison {
+    my ( $obj, $over ) = @_;
+    my $c = 0;
+    foreach my $prop (keys %$over) {
+        if ( exists $obj->{$prop} ) {
+            next if not defined $obj->{$prop} and not defined $over->{$prop};
+#            next if ( defined $obj->{$prop} and defined $over->{$prop} ) and ( $obj->{$prop} eq $over->{$prop} );
+#            if (
+#                 ( defined $obj->{$prop} and not defined $over->{$prop} ) or
+#                 ( not defined $obj->{$prop} and defined $over->{$prop} ) or
+#                 ( $obj->{$prop} ne $over->{$prop} ) 
+#               ) {
+                $log->debug( "pre_update_comparison: detected changed property $prop" );
+                $obj->{$prop} = $over->{$prop};
+                $c += 1;
+#            }
+        }
+    }
+    return $c;
+}
+
+
 1;
