@@ -51,11 +51,11 @@ App::Dochazka::REST::Util::Timestamp - date/time-related utilities
 
 =head1 VERSION
 
-Version 0.352
+Version 0.400
 
 =cut
 
-our $VERSION = '0.352';
+our $VERSION = '0.400';
 
 
 
@@ -101,7 +101,8 @@ This module provides the following exports:
 
 use Exporter qw( import );
 our @EXPORT_OK = qw( $today $today_ts $yesterday $yesterday_ts $tomorrow
-    $tomorrow_ts canonicalize_ts subtract_days tsrange_equal );
+    $tomorrow_ts $current_year $current_month canonicalize_ts subtract_days 
+    tsrange_equal );
 
 our $t = localtime;
 our $today = $t->ymd;
@@ -110,6 +111,8 @@ our $yesterday = ($t - ONE_DAY)->ymd;
 our $yesterday_ts = $yesterday . ' 00:00:00';
 our $tomorrow = ($t + ONE_DAY)->ymd;
 our $tomorrow_ts = $tomorrow . ' 00:00:00';
+our $current_year = $t->year;
+our $current_month = $t->mon;
 
 
 
